==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/et-EE/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Kohandatud väljad',
    'manage'                    => 'Manage',
    'field'		                => 'Väli',
    'about_fieldsets_title'		=> 'Andmeväljade kohta',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Krüpti selle valdkonna väärtus andmebaasis',
    'encrypt_field_help'      => 'HOIATUS: põllu krüptimine muudab selle otsingumatuks.',
    'encrypted'      	        => 'Krüpteeritud',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Mitmed väljad',
    'fieldsets'      	        => 'Väljadeklaratsioonid',
    'fieldset_name'           => 'Väljanägemise nimi',
    'field_name'              => 'Väljanimi',
    'field_values'            => 'Väljundväärtused',
    'field_values_help'       => 'Lisage valitavaid valikuid, üks rea kohta. Väljad tühja ridu peale esimese rea ignoreeritakse.',
    'field_element'           => 'Vormi element',
    'field_element_short'     => 'Element',
    'field_format'            => 'Vorming',
    'field_custom_format'     => 'Kohandatud vorming',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Nõutud',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Kasutatud mudelite järgi',
    'order'   		            => 'Telli',
    'create_fieldset'         => 'New Fieldset',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Uus kohandatud väli',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'Selle välja väärtust krüpteeritakse andmebaasis. Dežrooveeritud väärtust saab vaadata ainult administraatoritel',
    'show_in_email'     => 'Kas lisame selle välja väärtuse kasutajale väljastatud emailile? Krüpteerituid välju emailis pole näha',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'See väärtus peab olema kõikide vahendite puhul kordumatu',
    'unique' => 'Unique',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',

];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/et-EE/admin/custom_fields/general.php <==
<?php

return [
    'custom_fields'		        => 'Kohandatud väljad',
    'manage'                    => 'Manage',
    'field'		                => 'Väli',
    'about_fieldsets_title'		=> 'Andmeväljade kohta',
    'about_fieldsets_text'		=> 'Fieldsets allow you to create groups of custom fields that are frequently re-used for specific asset model types.',
    'custom_format'             => 'Custom Regex format...',
    'encrypt_field'      	        => 'Krüpti selle valdkonna väärtus andmebaasis',
    'encrypt_field_help'      => 'HOIATUS: põllu krüptimine muudab selle otsingumatuks.',
    'encrypted'      	        => 'Krüpteeritud',
    'fieldset'      	        => 'Fieldset',
    'qty_fields'      	      => 'Mitmed väljad',
    'fieldsets'      	        => 'Väljadeklaratsioonid',
    'fieldset_name'           => 'Väljanägemise nimi',
    'field_name'              => 'Väljanimi',
    'field_values'            => 'Väljundväärtused',
    'field_values_help'       => 'Lisage valitavaid valikuid, üks rea kohta. Väljad tühja ridu peale esimese rea ignoreeritakse.',
    'field_element'           => 'Vormi element',
    'field_element_short'     => 'Element',
    'field_format'            => 'Vorming',
    'field_custom_format'     => 'Kohandatud vorming',
    'field_custom_format_help'     => 'This field allows you to use a regex expression for validation. It should start with "regex:" - for example, to validate that a custom field value contains a valid IMEI (15 numeric digits), you would use <code>regex:/^[0-9]{15}$/</code>.',
    'required'   		          => 'Nõutud',
    'req'   		              => 'Req.',
    'used_by_models'   		    => 'Kasutatud mudelite järgi',
    'order'   		            => 'Telli',
    'create_fieldset'         => 'New Fieldset',
    'update_fieldset'         => 'Update Fieldset',
    'fieldset_does_not_exist'   => 'Fieldset :id does not exist',
    'fieldset_updated'         => 'Fieldset updated',
    'create_fieldset_title' => 'Create a new fieldset',
    'create_field'            => 'Uus kohandatud väli',
    'create_field_title' => 'Create a new custom field',
    'value_encrypted'      	        => 'The value of this field is encrypted in the database. Only users with permission to view encrypted custom fields will be able to view the decrypted value',
    'show_in_email'     => 'Kas lisame selle välja väärtuse kasutajale väljastatud emailile? Krüpteerituid välju emailis pole näha',
    'show_in_email_short' => 'Include in emails',
    'help_text' => 'Help Text',
    'help_text_description' => 'This is optional text that will appear below the form elements while editing an asset to provide context on the field.',
    'about_custom_fields_title' => 'About Custom Fields',
    'about_custom_fields_text' => 'Custom fields allow you to add arbitrary attributes to assets.',
    'add_field_to_fieldset' => 'Add Field to Fieldset',
    'make_optional' => 'Required - click to make optional',
    'make_required' => 'Optional - click to make required',
    'reorder' => 'Reorder',
    'db_field' => 'DB Field',
    'db_convert_warning' => 'WARNING. This field is in the custom fields table as <code>:db_column</code> but should be <code>:expected</code>.',
    'is_unique' => 'See väärtus peab olema kõikide vahendite puhul kordumatu',
    'unique' => 'Unique',
    'display_in_user_view' => 'Allow the checked out user to view these values in their View Assigned Assets page',
    'display_in_user_view_table' => 'Visible to User',
    'auto_add_to_fieldsets' => 'Automatically add this to every new fieldset',
    'add_to_preexisting_fieldsets' => 'Add to any existing fieldsets',
    'show_in_listview' => 'Show in list views by default. Authorized users will still be able to show/hide via the column selector',
    'show_in_listview_short' => 'Show in lists',
    'show_in_requestable_list_short' => 'Show in requestable assets list',
    'show_in_requestable_list' => 'Show value in requestable assets list. Encrypted fields will not be shown',
    'encrypted_options' => 'This field is encrypted, so some display options will not be available.',
    'display_checkin' => 'Display in checkin forms',
    'display_checkout' => 'Display in checkout forms',
    'display_audit' => 'Display in audit forms',
    'types' => [
        'text' => 'Text Box',
        'listbox' => 'List Box',
        'textarea' => 'Textarea (multi-line)',
        'checkbox' => 'Checkbox',
        'radio' => 'Radio Buttons',
    ],
];
